@@ -26,15 +26,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CC': 'x86_64-linux-gnu-gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O2 -Wall '
-           '-Wstrict-prototypes -g -fstack-protector '
-           '--param=ssp-buffer-size=4 -Wformat -Werror=format-security  -g '
-           '-flto -fuse-linker-plugin',
+           '-Wstrict-prototypes -g -fstack-protector-strong -Wformat '
+           '-Werror=format-security  -g -flto -fuse-linker-plugin '
+           '-ffat-lto-objects',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-g -fstack-protector --param=ssp-buffer-size=4 '
-                     '-Wformat -Werror=format-security',
+ 'CONFIGURE_CFLAGS': '-g -fstack-protector-strong -Wformat '
+                     '-Werror=format-security',
  'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
  'CONFIGURE_LDFLAGS': '-Wl,-Bsymbolic-functions -Wl,-z,relro',
@@ -44,14 +44,14 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'--without-ensurepip' '--with-system-expat' "
                 "'--with-system-libmpdec' '--with-system-ffi' "
                 "'--with-fpectl' 'CC=x86_64-linux-gnu-gcc' 'CFLAGS=-g "
-                '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                "-Werror=format-security ' 'LDFLAGS=-Wl,-Bsymbolic-functions "
-                "-Wl,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
+                "-fstack-protector-strong -Wformat -Werror=format-security ' "
+                "'LDFLAGS=-Wl,-Bsymbolic-functions -Wl,-z,relro' "
+                "'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.4m',
  'COREPYTHONPATH': ':plat-x86_64-linux-gnu',
- 'COVERAGE_INFO': '/build/python3.4-FrXMZZ/python3.4-3.4.3/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.4-FrXMZZ/python3.4-3.4.3/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/buildd/python3.4-3.4.2/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/buildd/python3.4-3.4.2/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -IInclude -I../Include -D_FORTIFY_SOURCE=2',
@@ -183,7 +183,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
- 'HAVE_GETENTROPY': 0,
  'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 0,
@@ -297,7 +296,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
- 'HAVE_RAND_EGD': 1,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -579,16 +577,16 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O2 -Wall '
-              '-Wstrict-prototypes -g -fstack-protector '
-              '--param=ssp-buffer-size=4 -Wformat -Werror=format-security  '
-              '',
+              '-Wstrict-prototypes -g -fstack-protector-strong -Wformat '
+              '-Werror=format-security  -g -flto -fuse-linker-plugin '
+              '-ffat-lto-objects',
  'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'PY_CORE_CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O2 -Wall '
-                   '-Wstrict-prototypes -g -fstack-protector '
-                   '--param=ssp-buffer-size=4 -Wformat '
-                   '-Werror=format-security   '
-                   '-Werror=declaration-after-statement -I. -IInclude '
-                   '-I../Include -D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
+                   '-Wstrict-prototypes -g -fstack-protector-strong -Wformat '
+                   '-Werror=format-security  -g -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -Werror=declaration-after-statement '
+                   '-I. -IInclude -I../Include -D_FORTIFY_SOURCE=2 -fPIC '
+                   '-DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -IInclude -I../Include -D_FORTIFY_SOURCE=2',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
@@ -601,7 +599,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.4-FrXMZZ/python3.4-3.4.3/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/buildd/python3.4-3.4.2/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -643,10 +641,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.4-FrXMZZ/python3.4-3.4.3/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/buildd/python3.4-3.4.2/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.4-FrXMZZ/python3.4-3.4.3/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/buildd/python3.4-3.4.2/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
@@ -672,8 +670,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.4-FrXMZZ/python3.4-3.4.3/build-shared',
- 'abs_srcdir': '/build/python3.4-FrXMZZ/python3.4-3.4.3/build-shared/..',
+ 'abs_builddir': '/build/buildd/python3.4-3.4.2/build-shared',
+ 'abs_srcdir': '/build/buildd/python3.4-3.4.2/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
