@@ -1,7 +1,7 @@
 package deprecate;
 use strict;
 use warnings;
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # our %Config can ignore %Config::Config, e.g. for testing
 our %Config;
@@ -10,9 +10,18 @@ unless (%Config) { require Config; *Config = \%Config::Config; }
 # Debian-specific change: recommend the separate Debian packages of
 # deprecated modules where available
 
-my %DEBIAN_PACKAGES = (
-    "Shell"		=> "libshell-perl",
-    "Devel::DProf"	=> "libdevel-dprof-perl"
+our %DEBIAN_PACKAGES = (
+    'CGI' => 'libcgi-pm-perl',
+    'CGI::Apache' => 'libcgi-pm-perl',
+    'CGI::Carp' => 'libcgi-pm-perl',
+    'CGI::Cookie' => 'libcgi-pm-perl',
+    'CGI::Fast' => 'libcgi-fast-perl',
+    'CGI::Pretty' => 'libcgi-pm-perl',
+    'CGI::Push' => 'libcgi-pm-perl',
+    'CGI::Switch' => 'libcgi-pm-perl',
+    'CGI::Util' => 'libcgi-pm-perl',
+    'Module::Build' => 'libmodule-build-perl',
+    'Package::Constants' => 'libpackage-constants-perl',
 );
 
 # This isn't a public API. It's internal to code maintained by the perl-porters
@@ -89,9 +98,9 @@ deprecate - Perl pragma for deprecating the core version of a module
 
 =head1 SYNOPSIS
 
-    use deprecate;	# always deprecate the module in which this occurs
+    use deprecate;  # always deprecate the module in which this occurs
 
-    use if $] > 5.010, 'deprecate';	# conditionally deprecate the module
+    use if $] > 5.010, 'deprecate'; # conditionally deprecate the module
 
 
 =head1 DESCRIPTION
